==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Misc/MiscDraw/Counter/ts/Counter_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Counter</name>
    <message>
        <location filename="../Counter.js" line="+64"/>
        <source>Position</source>
        <translation>Позиция</translation>
    </message>
    <message>
        <location filename="../Counter.ui" line="+17"/>
        <source>Start:</source>
        <translation>Начало:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Incr:</source>
        <translation>Прирост:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Precision:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Number of decimal digits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Prefix:</source>
        <translation>Префикс:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Suffix:</source>
        <translation>Суффикс:</translation>
    </message>
    <message>
        <location filename="../CounterInit.js" line="+2"/>
        <source>&amp;Counter</source>
        <translation>&amp;Счётчик</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Auto increment number</source>
        <translation>Автоматический прирост номеров</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Misc/MiscDraw/Counter/ts/Counter_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Counter</name>
    <message>
        <location filename="../Counter.js" line="+64"/>
        <source>Position</source>
        <translation>Позиция</translation>
    </message>
    <message>
        <location filename="../Counter.ui" line="+17"/>
        <source>Start:</source>
        <translation>Начало:</translation>
    </message>
    <message>
        <source>Incr:</source>
        <translation type="vanished">Прирост:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Increment:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Precision:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Number of decimal digits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Prefix:</source>
        <translation>Префикс:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Suffix:</source>
        <translation>Суффикс:</translation>
    </message>
    <message>
        <location filename="../CounterInit.js" line="+2"/>
        <source>&amp;Counter</source>
        <translation>&amp;Счётчик</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Auto increment number</source>
        <translation>Автоматический прирост номеров</translation>
    </message>
</context>
</TS>
